@@ -39,14 +39,14 @@
 #define GAMMA       2.0       /* expansion coefficient */
 
 
-double simplex1(double (*func)(int, int, int, double *, double *, int *, double ***, double *, double **, double **, int, int), int n1, int p, int T, double *nu, int *index, double ***X, double *gamma_k, double **invSk, double **invPsik, double *start, double EPSILON, double scale, int Mu_type, int trans_type)
+double simplex1(double (*func)(int, int, int, double *, double *, double ***, double *, double **, double **, int, int, int), int n1, int p, int T, double *nu, double ***X, double *gamma_k, double **invSk, double **invPsik, double *start, double EPSILON, double scale, int Mu_type, int trans_type, int la_type)
 {
   
   int vs;        	/* vertex with smallest value */
   int vh;        	/* vertex with next smallest value */
   int vg;        	/* vertex with largest value */
   
-  int i,j,m,row, n;
+  int i,j,m,row, n = 0;
   int k;		/* track the number of function evaluations */
   int itr;		/* track the number of iterations */
   
@@ -63,11 +63,12 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
   double min;
   
   double fsum,favg,s,cent;
-  n = 0;
-  for(j=0;j<p;j++){
-    if(index[j]==1){
-	n +=1;
-    }
+
+  if(la_type == 0){
+    n = p;
+  }
+  else if(la_type == 1){
+    n = 1;
   }
   
   /* dynamically allocate arrays */
@@ -120,7 +121,7 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
   
   /* find the initial function values */
   for (j=0;j<=n;j++) {
-    f[j] = func(n1, p, T, v[j], nu, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+    f[j] = func(n1, p, T, v[j], nu, X, gamma_k, invSk, invPsik, Mu_type, trans_type, la_type);
   }
   
   k = n+1;
@@ -167,7 +168,7 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
     for (j=0;j<=n-1;j++) {
       vr[j] = (1+ALPHA)*vm[j] - ALPHA*v[vg][j];
     }
-    fr = func(n1, p, T, vr, nu, index, X, gamma_k, invSk,invPsik, Mu_type, trans_type);
+    fr = func(n1, p, T, vr, nu, X, gamma_k, invSk,invPsik, Mu_type, trans_type, la_type);
     k++;
     
     /* added <= */
@@ -184,7 +185,7 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
       for (j=0;j<=n-1;j++) {
 	ve[j] = GAMMA*vr[j] + (1-GAMMA)*vm[j];
       }
-      fe = func(n1, p, T, ve, nu, index, X, gamma_k,invSk, invPsik, Mu_type, trans_type);
+      fe = func(n1, p, T, ve, nu, X, gamma_k,invSk, invPsik, Mu_type, trans_type, la_type);
       k++;
       
    
@@ -207,7 +208,7 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
       for (j=0;j<=n-1;j++) {
 	vc[j] = BETA*v[vg][j] + (1-BETA)*vm[j];
       }
-      fc = func(n1, p, T, vc, nu, index, X, gamma_k, invSk,invPsik, Mu_type, trans_type);
+      fc = func(n1, p, T, vc, nu, X, gamma_k, invSk,invPsik, Mu_type, trans_type, la_type);
       k++;
       if (fc < f[vg]) {
 	for (j=0;j<=n-1;j++) {
@@ -228,9 +229,9 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
 	    }
 	  }
 	}
-	f[vg] = func(n1, p, T, v[vg], nu, index, X, gamma_k, invSk,invPsik, Mu_type, trans_type);
+	f[vg] = func(n1, p, T, v[vg], nu, X, gamma_k, invSk,invPsik, Mu_type, trans_type, la_type);
 	k++;
-	f[vh] = func(n1, p, T, v[vh], nu, index, X, gamma_k,invSk, invPsik, Mu_type, trans_type);
+	f[vh] = func(n1, p, T, v[vh], nu, X, gamma_k,invSk, invPsik, Mu_type, trans_type, la_type);
 	k++;
 	
 	
@@ -266,7 +267,7 @@ double simplex1(double (*func)(int, int, int, double *, double *, int *, double
   for (j=0;j<n;j++) {
     start[j] = v[vs][j];
   }
-  min=func(n1, p, T, v[vs], nu, index, X, gamma_k, invSk, invPsik, Mu_type, trans_type);
+  min=func(n1, p, T, v[vs], nu, X, gamma_k, invSk, invPsik, Mu_type, trans_type, la_type);
   k++;
  
 
